# This spec file is derived from RHEL 9.1 GA package. It hopefully
# should get obsolete with RHEL 9.2 GA when libmspub-devel got included.
# Upstream: https://gitlab.com/redhat/centos-stream/rpms/libmspub
%global rhel_name libmspub
%global rhel_release 17
%global epel_release 1
%global _debugsource_template %{nil}

%global apiversion 0.1

Name: libmspub-epel
Version: 0.1.4
Release: 0.%{rhel_release}%{?dist}.%{epel_release}
Summary: A library for import of Microsoft Publisher documents

License: MPLv2.0
URL: http://wiki.documentfoundation.org/DLP/Libraries/libmspub
Source: http://dev-www.libreoffice.org/src/%{rhel_name}/%{rhel_name}-%{version}.tar.xz

Patch0: gcc10.patch

BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: help2man
BuildRequires: pkgconfig(icu-i18n)
BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(librevenge-generators-0.0)
BuildRequires: pkgconfig(librevenge-stream-0.0)
BuildRequires: pkgconfig(zlib)
BuildRequires: make

%description
Libmspub is library providing ability to interpret and import Microsoft
Publisher content into various applications. You can find it being used
in libreoffice.

%package -n %{rhel_name}-devel
Summary: Development files for %{rhel_name}
Requires: %{rhel_name}%{?_isa} = %{version}

%description -n %{rhel_name}-devel
The %{rhel_name}-devel package contains libraries and header files for
developing applications that use %{rhel_name}.

%prep
%autosetup -n %{rhel_name}-%{version} -p1

%build
%configure --disable-static --disable-silent-rules
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make_build

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.la
# rhbz#1001245 we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{rhel_name}

# generate and install man pages
 export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
 for tool in pub2raw pub2xhtml; do
     help2man -N -S '%{rhel_name} %{version}' -o ${tool}.1 %{buildroot}%{_bindir}/${tool}
 done
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 pub2*.1 %{buildroot}/%{_mandir}/man1

# Remove files shipped in RHEL 9
rm -f $RPM_BUILD_ROOT%{_libdir}/%{rhel_name}-%{apiversion}.so.*
rm -rf $RPM_BUILD_ROOT{%{_bindir},%{_mandir}}

%ldconfig_scriptlets

%files -n %{rhel_name}-devel
%doc ChangeLog
%{_includedir}/%{rhel_name}-%{apiversion}
%{_libdir}/%{rhel_name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{rhel_name}-%{apiversion}.pc

%changelog
* Sat Dec 10 2022 Robert Scheck <robert@fedoraproject.org> - 0.1.4-0.17.el9.1
- Transformed libmspub-0.1.4-17.el9 into libmspub-epel to achieve the
  missing libmspub-devel package for EPEL 9 until it's available with
  RHEL 9.2
  Related: rhbz#2144652

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 0.1.4-17
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Fri Apr 16 2021 Mohan Boddu <mboddu@redhat.com> - 0.1.4-16
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 14 2020 Tom Stellard <tstellar@redhat.com> - 0.1.4-13
- Use make macros
- https://fedoraproject.org/wiki/Changes/UseMakeBuildInstallMacro

* Sat May 16 2020 Pete Walter <pwalter@fedoraproject.org> - 0.1.4-12
- Rebuild for ICU 67

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Dec 14 2019 Jeff Law <law@redhat.com> - 0.1.4-10
- Fix missing #include for gcc-10

* Fri Nov 01 2019 Pete Walter <pwalter@fedoraproject.org> - 0.1.4-9
- Rebuild for ICU 65

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jan 25 2019 Jonathan Wakely <jwakely@redhat.com> - 0.1.4-6
- Rebuilt for Boost 1.69

* Wed Jan 23 2019 Pete Walter <pwalter@fedoraproject.org> - 0.1.4-5
- Rebuild for ICU 63

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Pete Walter <pwalter@fedoraproject.org> - 0.1.4-3
- Rebuild for ICU 62

* Mon Apr 30 2018 Pete Walter <pwalter@fedoraproject.org> - 0.1.4-2
- Rebuild for ICU 61.1

* Wed Feb 28 2018 David Tardon <dtardon@redhat.com> - 0.1.4-1
- new upstream release

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 0.1.3-2
- Rebuilt for Boost 1.66

* Tue Jan 02 2018 David Tardon <dtardon@redhat.com> - 0.1.3-1
- new upstream release

* Thu Nov 30 2017 Pete Walter <pwalter@fedoraproject.org> - 0.1.2-19
- Rebuild for ICU 60.1

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 03 2017 Jonathan Wakely <jwakely@redhat.com> - 0.1.2-16
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.2-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 0.1.2-13
- Rebuilt for Boost 1.63

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 0.1.2-12
- Rebuilt for Boost 1.63

* Fri Apr 15 2016 David Tardon <dtardon@redhat.com> - 0.1.2-11
- rebuild for ICU 57.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 0.1.2-9
- Rebuilt for Boost 1.60

* Wed Oct 28 2015 David Tardon <dtardon@redhat.com> - 0.1.2-8
- rebuild for ICU 56.1

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 0.1.2-7
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.2-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.1.2-5
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.1.2-3
- Rebuilt for GCC 5 C++11 ABI change

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.1.2-2
- Rebuild for boost 1.57.0

* Tue Dec 30 2014 David Tardon <dtardon@redhat.com> - 0.1.2-1
- new upstream release

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 0.1.1-3
- rebuild for ICU 53.1

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 01 2014 David Tardon <dtardon@redhat.com> - 0.1.0-1
- new upstream release

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon May 26 2014 David Tardon <dtardon@redhat.com> - 0.1.0-1
- new upstream release

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.0.6-7
- Rebuild for boost 1.55.0

* Wed Apr 09 2014 David Tardon <dtardon@redhat.com> - 0.0.6-6
- generate man pages

* Thu Feb 13 2014 David Tardon <dtardon@redhat.com> - 0.0.6-5
- rebuild for new ICU

* Fri Aug 30 2013 David Tardon <dtardon@redhat.com> - 0.0.6-4
- Resolves: rhbz#1001245 duplicate documentation files / potentially conflicting

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 0.0.6-2
- Rebuild for boost 1.54.0

* Tue May 14 2013 David Tardon <dtardon@redhat.com> - 0.0.6-1
- new release

* Wed Feb 20 2013 David Tardon <dtardon@redhat.com> - 0.0.5-1
- new release

* Wed Jan 30 2013 David Tardon <dtardon@redhat.com> - 0.0.4-1
- new release

* Fri Aug 24 2012 David Tardon <dtardon@redhat.com> - 0.0.3-1
- new release

* Fri Jul 27 2012 David Tardon <dtardon@redhat.com> - 0.0.2-3
- rebuilt for boost 1.50

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 David Tardon <dtardon@redhat.com> - 0.0.2-1
- Resolves: rhbz#840445 new release

* Thu Jul 12 2012 David Tardon <dtardon@redhat.com> 0.0.1-1
- new release

* Thu Jun 07 2012 David Tardon <dtardon@redhat.com> 0.0.0-1
- initial import
